==> haskell-persistent-2.13.1.2-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent
version:              2.13.1.2
visibility:           public
id:                   persistent-2.13.1.2-11poMH4vxb16uUgXmrQIPw
key:                  persistent-2.13.1.2-11poMH4vxb16uUgXmrQIPw
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  c8b614aef39dbd6e200e820dc276ab33
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.DeleteCascade
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.Statement Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.0.2/site-local/persistent-2.13.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/persistent-2.13.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/persistent-2.13.1.2
hs-libraries:         HSpersistent-2.13.1.2-11poMH4vxb16uUgXmrQIPw
depends:
    aeson-1.5.6.0-9b7PYeIt4IK50V585g1cEG
    attoparsec-0.14.4-GTUovz5zqDi6zhtjAcFzCG base-4.15.1.0
    base64-bytestring-1.2.1.0-Cmm20kzivR28lOWVTvnKrp
    blaze-html-0.9.1.2-4pOcrhmHcJE90UtusJZG2k bytestring-0.10.12.1
    conduit-1.3.4.2-4OESnOFAn3YLxnwTfxCzvi containers-0.6.4.1
    fast-logger-3.0.5-2wW0SpYYLsD5FHw9D0OgSm
    http-api-data-0.4.3-Bl0lKumxO9F1bzEvWIe6hl
    lift-type-0.1.0.1-D35eTUCvwh023OqKS2qJnE
    monad-logger-0.3.36-FSlW4TcUvTXIjYzN2carFi mtl-2.2.2
    path-pieces-0.2.1-H7eklAHLAbQDmNQh33Z06o
    resource-pool-0.2.3.2-Czx7chHlaXd9vF1kr2aJTe
    resourcet-1.2.4.3-A3UQmLnGJ4MLRi5DNZbYSg
    scientific-0.3.7.0-1z9G7slsH3XBcFZLCHnRNA
    silently-1.2.5.2-KvFvN8XiRhqBA56Sfh5QQ1 template-haskell-2.17.0.0
    text-1.2.5.0 th-lift-instances-0.1.19-AaFIfWZDkSs5G4waMVRft3
    time-1.9.3 transformers-0.5.6.2
    unliftio-0.2.21.0-6V2VPKgnS8NE0QRrQmE1YQ
    unliftio-core-0.2.0.1-HjGpVpPktr5Bc3kYrL6LtS
    unordered-containers-0.2.16.0-CwffDPZxPuFHBx4xcBeO
    vector-0.12.3.1-FGR30quEvBKIVgcX0eclul

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.13.1.2-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent
version:              2.13.1.2
visibility:           public
id:                   persistent-2.13.1.2-Ic0mRHcDwUhnNZgh29Iqo
key:                  persistent-2.13.1.2-Ic0mRHcDwUhnNZgh29Iqo
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  f24643ae1d5265e06d1176f34af06ed3
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.DeleteCascade
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.Statement Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.0.2/site-local/persistent-2.13.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/persistent-2.13.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/persistent-2.13.1.2
hs-libraries:         HSpersistent-2.13.1.2-Ic0mRHcDwUhnNZgh29Iqo
depends:
    aeson-1.5.6.0-AIOjF99b4i15RTiIgKIYjO
    attoparsec-0.14.4-D5og7XyPWkJ5mYaAXELiLF base-4.15.1.0
    base64-bytestring-1.2.1.0-9KSPymfrMIbFRL5bRa2eDU
    blaze-html-0.9.1.2-LiVe7r0ip9zJ8lLrH9JuPb bytestring-0.10.12.1
    conduit-1.3.4.2-1Dj2Rn8d5gx9afxHW7mS2C containers-0.6.4.1
    fast-logger-3.1.0-6uq4osKXM3Q7YZG94t2YFe
    http-api-data-0.4.3-A1NRJ6rfnPn4rebTJ4BKv4
    lift-type-0.1.0.1-D35eTUCvwh023OqKS2qJnE
    monad-logger-0.3.36-InBKbo8SqwwpG6dTv7dmb mtl-2.2.2
    path-pieces-0.2.1-H7eklAHLAbQDmNQh33Z06o
    resource-pool-0.2.3.2-3QrgUgmi42GJpjiqkhDnQk
    resourcet-1.2.4.3-6xSSDlJt6Qw9ePbxI43Doy
    scientific-0.3.7.0-65DCAuzTAutLqM6Vcsju3Y
    silently-1.2.5.2-KvFvN8XiRhqBA56Sfh5QQ1 template-haskell-2.17.0.0
    text-1.2.5.0 th-lift-instances-0.1.19-KNVcry4OPxY2UK0a2dipOR
    time-1.9.3 transformers-0.5.6.2
    unliftio-0.2.21.0-55WXglRB9J58lk5vI4DHEU
    unliftio-core-0.2.0.1-HjGpVpPktr5Bc3kYrL6LtS
    unordered-containers-0.2.17.0-3BdVQ0XjWEwL87G4XZjXWP
    vector-0.12.3.1-5HK1DqtCbep8rMk53O5plV

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
